function [R0, t_c5] = exit_scenarios(Taui, C, tc_b4ld, exits)
% This function calculates the R0 value for possible exit strategies
% - 1) Only skilled trade and elementary occupations returning to normal which account for 10\% of the population of Northern Ireland.
% -  2) Professional occupations, managers and administrative occupations returning to normal which account for 16.5\% of the population.
% - 3) Professional occupations + managers + administrative occupations + skilled trade + elementary occupations returning to normal: 26.5\% of the population.
% - 4) Sales and costumer services + Leisure and other service occupations returning to normal which account for 8\% of the population of Northern Ireland returning to work. However, in this scenario the BBC pandemic contact matrix correxponding to \textit{other} activities is also considered in estimating the total number of contacts. 
% - 5) Removing all restrictions with schools remaining closed normal which account for most of the population (98\%) returning to normal work environment except teaching and educational occupations. 
% - 6) Removing all restrictions 
%% 7) removing all
t_c1 = tc_b4ld;
tot_tc1 = sum(t_c1(:));
R0(7,:) = Taui.* tot_tc1*1/0.5338;


%% 6) Removing all restrictions with schools remaining closed normal which account for most of the population (98\%) returning to normal work environment except teaching and educational occupations. 

t_c2 = (C.home.wk + C.other.wk+ C.work.wk*0.967)*5+(C.home.wknd+C.other.wknd+C.work.wknd*exits(6))*2;
t_c2 = t_c2/7;
tot_tc2 = sum(t_c2(:));
R0(6,:) = Taui.* tot_tc2*1/0.5338;

%% 1) Only skilled trade and elementary occupations returning to normal which account for 10\% of the population of Northern Ireland.
aa_sc1 = 2.35;
h = C.work.wk(4:15 , 4:15) * (exits(2))*aa_sc1;
h1 = zeros(16, 16) ;
h1(4:15, 4:15) = h;

h_wknd = C.work.wknd(4:15 , 4:15) * (exits(2))*aa_sc1;
h1_wknd = zeros(16, 16) ;
h1_wknd(4:15, 4:15) = h_wknd;

t_c3 = (C.home.wk+h1)*5 + (C.home.wknd+h1_wknd)*2;
clear h h1 h_wknd h1_wknd
t_c3 = t_c3/7;
tot_tc3 = sum(t_c3(:));
R0(1,:) = Taui.* tot_tc3*1/0.5338;

%% 2)  Professional occupations, managers and administrative occupations returning to normal which account for 16.5\% of the population.
aa_sc2 = 1.30;
h = C.work.wk(4:15 , 4:15) * exits(3)*aa_sc2;
h1 = zeros(16, 16) ;
h1(4:15, 4:15) = h;

h_wknd = C.work.wknd(4:15 , 4:15) * exits(3)*aa_sc2;
h1_wknd = zeros(16, 16) ;
h1_wknd(4:15, 4:15) = h_wknd;

t_c4 = (C.home.wk+h1)*5 + (C.home.wknd+h1_wknd)*2;
clear h h1 h_wknd h1_wknd
t_c4 = t_c4/7;
tot_tc4 = sum(t_c4(:));
R0(2,:) = Taui * tot_tc4*1/0.5338;

%% 3) Professional occupations + managers + administrative occupations + skilled trade + elementary occupations returning to normal: 26.5\% of the population.
aa_sc3 = 3.32;
h = C.work.wk(4:15 , 4:15) * exits(4)*aa_sc3;
h1 = zeros(16, 16) ;
h1(4:15, 4:15) = h;

h_wknd = C.work.wknd(4:15 , 4:15) * exits(4)*aa_sc3;
h1_wknd = zeros(16, 16) ;
h1_wknd(4:15, 4:15) = h_wknd;

t_c5 = (C.home.wk+h1)*5 + (C.home.wknd+h1_wknd)*2;
clear h h1 h_wknd h1_wknd
t_c5 = t_c5/7;
tot_tc5 = sum(t_c5(:));
R0(3,:) = Taui.* tot_tc5*1/0.5338;

%% 5) Sales and costumer services + Leisure and other service occupations returning to normal which account for 8\% of the population of Northern Ireland returning to work. However, in this scenario the BBC pandemic contact matrix correxponding to \textit{other} activities is also considered in estimating the total number of contacts. 
aa_sc5 = 1.08;
h = C.work.wk(4:15 , 4:15) * exits(5)*aa_sc5;
h1 = zeros(16, 16) ;
h1(4:15, 4:15) = h;

h_wknd = C.work.wknd(4:15 , 4:15) * exits(5)*aa_sc5;
h1_wknd = zeros(16, 16) ;
h1_wknd(4:15, 4:15) = h_wknd;

t_c6 = (C.home.wk+h1+C.other.wk)*5 + (C.home.wknd+h1_wknd+C.other.wknd)*2;
clear h h1 h_wknd h1_wknd
t_c6 = t_c6/7;
tot_tc6 = sum(t_c6(:));
R0(5,:) = Taui * tot_tc6*1/0.5338;
%% 4) shoold open + skilled trade and elementary occupations returning to normal which account for 10\% of the population of Northern Ireland.
aa_sc4 = 3.43;
h = C.work.wk(4:15 , 4:15) * (exits(2))*aa_sc4+C.school.wk(4:15, 4:15)+C.work.wk(4:15 , 4:15) * (exits(5));
h1 = zeros(16, 16) ;
h1(4:15, 4:15) = h;

h_wknd = C.work.wknd(4:15 , 4:15) * (exits(2))*aa_sc4 +C.school.wknd(4:15, 4:15)+ C.work.wknd(4:15 , 4:15)*(exits(5));
h1_wknd = zeros(16, 16) ;
h1_wknd(4:15, 4:15) = h_wknd;

t_c3 = (C.home.wk+h1)*5 + (C.home.wknd+h1_wknd)*2;
clear h h1 h_wknd h1_wknd
t_c3 = t_c3/7;
tot_tc3 = sum(t_c3(:));
R0(4,:) = Taui.* tot_tc3*1/0.5338;
